@@ -33,7 +33,7 @@ import zipfile
 
 LOG = logging.getLogger('MQ2')
 
-__version__ = '0.1.2'
+__version__ = '0.2.0'
 
 
 def set_tmp_folder():
@@ -58,9 +58,10 @@ def extract_zip(filename, extract_dir):
     if not os.path.exists(extract_dir):
         try:
             os.mkdir(extract_dir)
-        except IOError, err:
+        except IOError, err:  # pragma: no cover
             LOG.info("Could not generate the folder %s" % extract_dir)
             LOG.debug("Error: %s" % err)
+            return
 
     if zipfile.is_zipfile(filename):
         try:
@@ -70,24 +71,48 @@ def extract_zip(filename, extract_dir):
                     curdir = os.path.join(extract_dir, os.path.dirname(name))
                     if not os.path.exists(curdir):
                         os.mkdir(curdir)
+                        continue
                 outfile = open(os.path.join(extract_dir, name), 'wb')
                 outfile.write(zfile.read(name))
                 outfile.flush()
                 outfile.close()
             zfile.close()
-        except IOError, err:
+        except IOError, err:  # pragma: no cover
+            LOG.info("Error while extracting the zip archive.")
             LOG.debug("Error: %s" % err)
     else:
-        try:
+        try:  # pragma: no cover  We only have zipfile to test with
             tar = tarfile.open(filename)
             tar.extractall(extract_dir)
             tar.close()
-        except tarfile.ReadError, err:
+        except tarfile.ReadError, err:  # pragma: no cover
+            LOG.info("Error while extracting the tarball.")
             LOG.debug("Error: %s" % err)
 
     return extract_dir
 
 
+def get_matrix_dimensions(filename):
+    """ Reads in a matrix file (comma separated) and returns the number
+    of rows and columns.
+    :arg filename, the full path to the file to read.
+    """
+    stream = None
+    try:
+        stream = open(filename, 'r')
+        length = len(stream.readlines())
+        stream.seek(0)
+        width = len(stream.readline().split(','))
+        return (length, width)
+    except IOError, err:  # pragma: no cover
+        LOG.info("Something wrong happend while reading the file %s "\
+        % filename)
+        LOG.debug("ERROR: %s" % err)
+    finally:
+        if stream:
+            stream.close()
+
+
 def read_input_file(filename, sep='\t'):
     """Reads a given inputfile (tab delimited) and returns a matrix
     (list of list).
@@ -99,7 +124,7 @@ def read_input_file(filename, sep='\t'):
         stream = open(filename, 'r')
         for row in stream:
             output.append(row.strip().split(sep))
-    except IOError, err:
+    except IOError, err:  # pragma: no cover
         LOG.info("Something wrong happend while reading the file %s "\
         % filename)
         LOG.debug("ERROR: %s" % err)
